@@ -3,6 +3,7 @@ const {gettext: _} = domain('arcmenu');
 
 export const DASH_TO_PANEL_UUID = 'dash-to-panel@jderose9.github.com';
 export const AZTASKBAR_UUID = 'aztaskbar@aztaskbar.gitlab.com';
+export const RESOURCE_PATH = 'resource:///org/gnome/shell/extensions/arcmenu/icons/scalable';
 
 export const ClutterAction = {
     CLICK: 0,
@@ -94,11 +95,11 @@ export const SoftwareManagerIDs = ['org.manjaro.pamac.manager.desktop', 'pamac-m
     'org.gnome.Software.desktop', 'tr.org.pardus.software.desktop'];
 
 export const Categories = [
-    {CATEGORY: CategoryType.FAVORITES, NAME: _('Favorites'), ICON: 'emote-love-symbolic'},
-    {CATEGORY: CategoryType.FREQUENT_APPS, NAME: _('Frequent Apps'), ICON: 'user-bookmarks-symbolic'},
-    {CATEGORY: CategoryType.ALL_PROGRAMS, NAME: _('All Apps'), ICON: 'view-app-grid-symbolic'},
-    {CATEGORY: CategoryType.PINNED_APPS, NAME: _('Pinned Apps'), ICON: 'view-pin-symbolic'},
-    {CATEGORY: CategoryType.RECENT_FILES, NAME: _('Recent Files'), ICON: 'document-open-recent-symbolic'},
+    {CATEGORY: CategoryType.FAVORITES, NAME: _('Favorites'), IMAGE: 'emote-love-symbolic'},
+    {CATEGORY: CategoryType.FREQUENT_APPS, NAME: _('Frequent Apps'), IMAGE: 'user-bookmarks-symbolic'},
+    {CATEGORY: CategoryType.ALL_PROGRAMS, NAME: _('All Apps'), IMAGE: 'view-app-grid-symbolic'},
+    {CATEGORY: CategoryType.PINNED_APPS, NAME: _('Pinned Apps'), IMAGE: 'view-pin-symbolic'},
+    {CATEGORY: CategoryType.RECENT_FILES, NAME: _('Recent Files'), IMAGE: 'document-open-recent-symbolic'},
 ];
 
 export const TooltipLocation = {
@@ -269,128 +270,117 @@ export const PowerDisplayStyle = {
 };
 
 export const PowerOptions = [
-    {TYPE: PowerType.LOGOUT, ICON: 'system-log-out-symbolic', NAME: _('Log Out...')},
-    {TYPE: PowerType.LOCK, ICON: 'changes-prevent-symbolic', NAME: _('Lock')},
-    {TYPE: PowerType.RESTART, ICON: 'system-reboot-symbolic', NAME: _('Restart...')},
-    {TYPE: PowerType.POWER_OFF, ICON: 'system-shutdown-symbolic', NAME: _('Power Off...')},
-    {TYPE: PowerType.SUSPEND, ICON: 'media-playback-pause-symbolic', NAME: _('Suspend')},
-    {TYPE: PowerType.HYBRID_SLEEP, ICON: 'weather-clear-night-symbolic', NAME: _('Hybrid Sleep')},
-    {TYPE: PowerType.HIBERNATE, ICON: 'document-save-symbolic', NAME: _('Hibernate')},
-    {TYPE: PowerType.SWITCH_USER, ICON: 'system-switch-user-symbolic', NAME: _('Switch User')},
+    {TYPE: PowerType.LOGOUT, IMAGE: 'system-log-out-symbolic', NAME: _('Log Out...')},
+    {TYPE: PowerType.LOCK, IMAGE: 'changes-prevent-symbolic', NAME: _('Lock')},
+    {TYPE: PowerType.RESTART, IMAGE: 'system-reboot-symbolic', NAME: _('Restart...')},
+    {TYPE: PowerType.POWER_OFF, IMAGE: 'system-shutdown-symbolic', NAME: _('Power Off...')},
+    {TYPE: PowerType.SUSPEND, IMAGE: 'media-playback-pause-symbolic', NAME: _('Suspend')},
+    {TYPE: PowerType.HYBRID_SLEEP, IMAGE: 'weather-clear-night-symbolic', NAME: _('Hybrid Sleep')},
+    {TYPE: PowerType.HIBERNATE, IMAGE: 'document-save-symbolic', NAME: _('Hibernate')},
+    {TYPE: PowerType.SWITCH_USER, IMAGE: 'system-switch-user-symbolic', NAME: _('Switch User')},
 ];
 
-// Icon type for the menu button
-// set 'menu-button-icon' enum setting to value of desired icon type.
-export const MenuIconType = {
-    MENU_ICON: 0,
-    DISTRO_ICON: 1,
-    CUSTOM: 2,
-};
-
-// Object order in MenuIcons array corresponds to the integer value of 'arc-menu-icon' setting
-// i.e 'arc-menu-icon' value of 0 is arcmenu-logo-symbolic.
+// Deprecated - icons are now packaged in GResource.
 export const MenuIcons = [
-    {PATH: 'icon-arcmenu-logo-symbolic'},
-    {PATH: 'icon-arcmenu-logo-alt-symbolic'},
-    {PATH: 'icon-arcmenu-old-symbolic'},
-    {PATH: 'icon-arcmenu-old-alt-symbolic'},
-    {PATH: 'icon-arcmenu-oldest-symbolic'},
-    {PATH: 'icon-curved-a-symbolic'},
-    {PATH: 'icon-focus-symbolic'},
-    {PATH: 'icon-triple-dash-symbolic'},
-    {PATH: 'icon-whirl-symbolic'},
-    {PATH: 'icon-whirl-circle-symbolic'},
-    {PATH: 'icon-sums-symbolic'},
-    {PATH: 'icon-arrow-symbolic'},
-    {PATH: 'icon-lins-symbolic'},
-    {PATH: 'icon-diamond-square-symbolic'},
-    {PATH: 'icon-octo-maze-symbolic'},
-    {PATH: 'icon-search-glass-symbolic'},
-    {PATH: 'icon-transform-symbolic'},
-    {PATH: 'icon-toxic2-symbolic'},
-    {PATH: 'icon-alien-symbolic'},
-    {PATH: 'icon-cloud-symbolic'},
-    {PATH: 'icon-dragon-symbolic'},
-    {PATH: 'icon-fly-symbolic'},
-    {PATH: 'icon-pacman-symbolic'},
-    {PATH: 'icon-peaks-symbolic'},
-    {PATH: 'icon-pie-symbolic'},
-    {PATH: 'icon-pointer-symbolic'},
-    {PATH: 'icon-toxic-symbolic'},
-    {PATH: 'icon-tree-symbolic'},
-    {PATH: 'icon-zegon-symbolic'},
-    {PATH: 'icon-apps-symbolic'},
-    {PATH: 'icon-bug-symbolic'},
-    {PATH: 'icon-cita-symbolic'},
-    {PATH: 'icon-dragonheart-symbolic'},
-    {PATH: 'icon-eclipse-symbolic'},
-    {PATH: 'icon-football-symbolic'},
-    {PATH: 'icon-heddy-symbolic'},
-    {PATH: 'icon-helmet-symbolic'},
-    {PATH: 'icon-paint-palette-symbolic'},
-    {PATH: 'icon-peeks-symbolic'},
-    {PATH: 'icon-record-symbolic'},
-    {PATH: 'icon-saucer-symbolic'},
-    {PATH: 'icon-step-symbolic'},
-    {PATH: 'icon-vancer-symbolic'},
-    {PATH: 'icon-vibe-symbolic'},
-    {PATH: 'icon-start-box-symbolic'},
-    {PATH: 'icon-dimond-win-symbolic'},
-    {PATH: 'icon-dolphin-symbolic'},
-    {PATH: 'icon-dota-symbolic'},
-    {PATH: 'icon-football2-symbolic'},
-    {PATH: 'icon-loveheart-symbolic'},
-    {PATH: 'icon-pyrimid-symbolic'},
-    {PATH: 'icon-rewind-symbolic'},
-    {PATH: 'icon-snap-symbolic'},
-    {PATH: 'icon-time-symbolic'},
-    {PATH: 'icon-3d-symbolic'},
-    {PATH: 'icon-a-symbolic'},
-    {PATH: 'icon-app-launcher-symbolic'},
-    {PATH: 'icon-bat-symbolic'},
-    {PATH: 'icon-dra-symbolic'},
-    {PATH: 'icon-equal-symbolic'},
-    {PATH: 'icon-gnacs-symbolic'},
-    {PATH: 'icon-groove-symbolic'},
-    {PATH: 'icon-kaaet-symbolic'},
-    {PATH: 'icon-launcher-symbolic'},
-    {PATH: 'icon-pac-symbolic'},
-    {PATH: 'icon-robots-symbolic'},
-    {PATH: 'icon-sheild-symbolic'},
-    {PATH: 'icon-somnia-symbolic'},
-    {PATH: 'icon-utool-symbolic'},
-    {PATH: 'icon-swirl-symbolic'},
-    {PATH: 'icon-round-symbolic'},
-    {PATH: 'view-app-grid-symbolic'},
+    {IMAGE: 'icon-arcmenu-logo-symbolic'},
+    {IMAGE: 'icon-arcmenu-logo-alt-symbolic'},
+    {IMAGE: 'icon-arcmenu-old-symbolic'},
+    {IMAGE: 'icon-arcmenu-old-alt-symbolic'},
+    {IMAGE: 'icon-arcmenu-oldest-symbolic'},
+    {IMAGE: 'icon-curved-a-symbolic'},
+    {IMAGE: 'icon-focus-symbolic'},
+    {IMAGE: 'icon-triple-dash-symbolic'},
+    {IMAGE: 'icon-whirl-symbolic'},
+    {IMAGE: 'icon-whirl-circle-symbolic'},
+    {IMAGE: 'icon-sums-symbolic'},
+    {IMAGE: 'icon-arrow-symbolic'},
+    {IMAGE: 'icon-lins-symbolic'},
+    {IMAGE: 'icon-diamond-square-symbolic'},
+    {IMAGE: 'icon-octo-maze-symbolic'},
+    {IMAGE: 'icon-search-glass-symbolic'},
+    {IMAGE: 'icon-transform-symbolic'},
+    {IMAGE: 'icon-toxic2-symbolic'},
+    {IMAGE: 'icon-alien-symbolic'},
+    {IMAGE: 'icon-cloud-symbolic'},
+    {IMAGE: 'icon-dragon-symbolic'},
+    {IMAGE: 'icon-fly-symbolic'},
+    {IMAGE: 'icon-pacman-symbolic'},
+    {IMAGE: 'icon-peaks-symbolic'},
+    {IMAGE: 'icon-pie-symbolic'},
+    {IMAGE: 'icon-pointer-symbolic'},
+    {IMAGE: 'icon-toxic-symbolic'},
+    {IMAGE: 'icon-tree-symbolic'},
+    {IMAGE: 'icon-zegon-symbolic'},
+    {IMAGE: 'icon-apps-symbolic'},
+    {IMAGE: 'icon-bug-symbolic'},
+    {IMAGE: 'icon-cita-symbolic'},
+    {IMAGE: 'icon-dragonheart-symbolic'},
+    {IMAGE: 'icon-eclipse-symbolic'},
+    {IMAGE: 'icon-football-symbolic'},
+    {IMAGE: 'icon-heddy-symbolic'},
+    {IMAGE: 'icon-helmet-symbolic'},
+    {IMAGE: 'icon-paint-palette-symbolic'},
+    {IMAGE: 'icon-peeks-symbolic'},
+    {IMAGE: 'icon-record-symbolic'},
+    {IMAGE: 'icon-saucer-symbolic'},
+    {IMAGE: 'icon-step-symbolic'},
+    {IMAGE: 'icon-vancer-symbolic'},
+    {IMAGE: 'icon-vibe-symbolic'},
+    {IMAGE: 'icon-start-box-symbolic'},
+    {IMAGE: 'icon-dimond-win-symbolic'},
+    {IMAGE: 'icon-dolphin-symbolic'},
+    {IMAGE: 'icon-dota-symbolic'},
+    {IMAGE: 'icon-football2-symbolic'},
+    {IMAGE: 'icon-loveheart-symbolic'},
+    {IMAGE: 'icon-pyrimid-symbolic'},
+    {IMAGE: 'icon-rewind-symbolic'},
+    {IMAGE: 'icon-snap-symbolic'},
+    {IMAGE: 'icon-time-symbolic'},
+    {IMAGE: 'icon-3d-symbolic'},
+    {IMAGE: 'icon-a-symbolic'},
+    {IMAGE: 'icon-app-launcher-symbolic'},
+    {IMAGE: 'icon-bat-symbolic'},
+    {IMAGE: 'icon-dra-symbolic'},
+    {IMAGE: 'icon-equal-symbolic'},
+    {IMAGE: 'icon-gnacs-symbolic'},
+    {IMAGE: 'icon-groove-symbolic'},
+    {IMAGE: 'icon-kaaet-symbolic'},
+    {IMAGE: 'icon-launcher-symbolic'},
+    {IMAGE: 'icon-pac-symbolic'},
+    {IMAGE: 'icon-robots-symbolic'},
+    {IMAGE: 'icon-sheild-symbolic'},
+    {IMAGE: 'icon-somnia-symbolic'},
+    {IMAGE: 'icon-utool-symbolic'},
+    {IMAGE: 'icon-swirl-symbolic'},
+    {IMAGE: 'icon-round-symbolic'},
+    {IMAGE: 'view-app-grid-symbolic'},
 ];
-
-// Object order in DistroIcons array corresponds to the integer value of 'distro-icon' setting
-// i.e 'distro-icon' value of 3 is manjaro-logo.
+// Deprecated - icons are now packaged in GResource.
 export const DistroIcons = [
-    {PATH: 'distro-gnome-symbolic', NAME: 'GNOME'},
-    {PATH: 'distro-debian-symbolic', NAME: 'Debian'},
-    {PATH: 'distro-fedora-symbolic', NAME: 'Fedora'},
-    {PATH: 'distro-manjaro-symbolic', NAME: 'Manjaro'},
-    {PATH: 'distro-pop-os-symbolic', NAME: 'Pop!_OS'},
-    {PATH: 'distro-ubuntu-symbolic', NAME: 'Ubuntu'},
-    {PATH: 'distro-arch-symbolic', NAME: 'Arch'},
-    {PATH: 'distro-opensuse-symbolic', NAME: 'OpenSUSE'},
-    {PATH: 'distro-raspbian-symbolic', NAME: 'Raspbian'},
-    {PATH: 'distro-kali-linux-symbolic', NAME: 'Kali Linux'},
-    {PATH: 'distro-pureos-symbolic', NAME: 'PureOS'},
-    {PATH: 'distro-solus-symbolic', NAME: 'Solus'},
-    {PATH: 'distro-budgie-symbolic', NAME: 'Budgie'},
-    {PATH: 'distro-gentoo-symbolic', NAME: 'Gentoo'},
-    {PATH: 'distro-mx-symbolic', NAME: 'MX Linux'},
-    {PATH: 'distro-redhat-symbolic', NAME: 'Redhat'},
-    {PATH: 'distro-voyager-symbolic', NAME: 'Voyager'},
-    {PATH: 'distro-zorin-symbolic', NAME: 'Zorin OS'},
-    {PATH: 'distro-endeavour-symbolic', NAME: 'Endeavour'},
-    {PATH: 'distro-nobara-symbolic', NAME: 'Nobara'},
-    {PATH: 'distro-pardus-symbolic', NAME: 'Pardus'},
-    {PATH: 'distro-cachyos-symbolic', NAME: 'CachyOS'},
-    {PATH: 'distro-nixos-symbolic', NAME: 'NixOS'},
-    {PATH: 'distro-oreon-symbolic', NAME: 'Oreon OS'},
+    {IMAGE: 'distro-gnome-symbolic'},
+    {IMAGE: 'distro-debian-symbolic'},
+    {IMAGE: 'distro-fedora-symbolic'},
+    {IMAGE: 'distro-manjaro-symbolic'},
+    {IMAGE: 'distro-pop-os-symbolic'},
+    {IMAGE: 'distro-ubuntu-symbolic'},
+    {IMAGE: 'distro-arch-symbolic'},
+    {IMAGE: 'distro-opensuse-symbolic'},
+    {IMAGE: 'distro-raspbian-symbolic'},
+    {IMAGE: 'distro-kali-linux-symbolic'},
+    {IMAGE: 'distro-pureos-symbolic'},
+    {IMAGE: 'distro-solus-symbolic'},
+    {IMAGE: 'distro-budgie-symbolic'},
+    {IMAGE: 'distro-gentoo-symbolic'},
+    {IMAGE: 'distro-mx-symbolic'},
+    {IMAGE: 'distro-redhat-symbolic'},
+    {IMAGE: 'distro-voyager-symbolic'},
+    {IMAGE: 'distro-zorin-symbolic'},
+    {IMAGE: 'distro-endeavour-symbolic'},
+    {IMAGE: 'distro-nobara-symbolic'},
+    {IMAGE: 'distro-pardus-symbolic'},
+    {IMAGE: 'distro-cachyos-symbolic'},
+    {IMAGE: 'distro-nixos-symbolic'},
+    {IMAGE: 'distro-oreon-symbolic'},
 ];
 
 export const MenuLayout = {
@@ -577,7 +567,7 @@ export const MenuStyles = [
     },
 ];
 
-export const ArcMenuLogoSymbolic = '/icons/arcmenu-logo-symbolic.svg';
+export const ArcMenuLogoSymbolic = 'arcmenu-logo-symbolic';
 
 export const TranslatableSettingsStrings = [_('Software'), _('Settings'), _('Tweaks'), _('Terminal'),
     _('Activities Overview'), _('ArcMenu Settings'), _('Files')];
@@ -619,32 +609,3 @@ export const ShortcutCommands = {
     PANEL_EXTENSION_SETTINGS: 'ArcMenu_PanelExtensionSettings',
     ARCMENU_ICON: 'ArcMenu_ArcMenuIcon',
 };
-
-export const DistroIconsDisclaimer = '<i>All brand icons are trademarks of their respective owners.' +
-            ' The use of these trademarks does not indicate endorsement of the trademark holder ' +
-            'by ArcMenu project, nor vice versa.' +
-            ' Please do not use brand logos for any purpose except to represent the company, ' +
-            'product, or service to which they refer.</i>' +
-    '\n\n•   <b>GNOME®</b> - The GNOME name and logo are trademarks of the GNOME Foundation.' +
-    '\n\n•   <b>Ubuntu®</b> - Ubuntu name and Ubuntu logo are trademarks of Canonical© Ltd.' +
-    '\n\n•   <b>Fedora®</b> - Fedora and the Infinity design logo are trademarks of Red Hat, Inc.' +
-    '\n\n•   <b>Debian®</b> - is a registered trademark owned by Software in the Public Interest.' +
-    '\n\n•   <b>Manjaro®</b> - logo and name are trademarks of Manjaro GmbH &amp; Co. KG' +
-    '\n\n•   <b>Pop_OS!®</b> - logo and name are trademarks of system 76© Inc.' +
-    '\n\n•   <b>Arch Linux™</b> - The stylized Arch Linux logo is a recognized trademark of Arch Linux, ' +
-                'copyright 2002–2017 Judd Vinet and Aaron Griffin.' +
-    '\n\n•   <b>openSUSE®</b> - logo and name 2001–2020 SUSE LLC, © 2005–2020 openSUSE Contributors &amp; others.' +
-    '\n\n•   <b>Raspberry Pi®</b> - logo and name are part of Raspberry Pi Foundation UK Registered Charity 1129409' +
-    '\n\n•   <b>Kali Linux™</b> - logo and name are part of © OffSec Services Limited 2020' +
-    '\n\n•   <b>PureOS</b> - logo and name are developed by members of the Purism community' +
-    '\n\n•   <b>Solus</b> - logo and name are copyright © 2014–2018 by Solus Project' +
-    '\n\n•   <b>Gentoo Authors©</b> - 2001–2020 Gentoo is a trademark of the Gentoo Foundation, Inc.' +
-    '\n\n•   <b>Voyager© Linux</b> - name and logo' +
-    '\n\n•   <b>MX Linux©</b> - 2020 - Linux - is the registered trademark of Linus Torvalds ' +
-                'in the U.S. and other countries.' +
-    '\n\n•   <b>Red Hat, Inc.©</b> - Copyright 2020 name and logo' +
-    '\n\n•   <b>Pardus</b> - name and logo are copyright © 2003-2023 by TUBITAK ULAKBIM' +
-    '\n\n•   <b>ZORIN OS</b> - The "Z" logomark is a registered trademark of Zorin Technology Group Ltd. ' +
-                'Copyright © 2019 - 2021 Zorin Technology Group Ltd' +
-    '\n\n•   <b>NixOS</b> - The logo is made available under a <a href="https://creativecommons.org/licenses/by/4.0/">CC-BY license</a>. ' +
-                'Logo designed by Tim Cuthbertson (@timbertson)';
